@@ -37,6 +37,7 @@ class SVGShape:
     stroke_dashoffset: float = 1.0
     stroke_opacity: float = 1.0
     opacity: float = 1.0
+    transform: str = ""
 
     def _copy_common_fields(
         self,
@@ -52,6 +53,7 @@ class SVGShape:
         stroke_dashoffset,
         stroke_opacity,
         opacity,
+        transform,
     ):
         self.id = id
         self.clip_path = clip_path
@@ -65,6 +67,7 @@ class SVGShape:
         self.stroke_dashoffset = stroke_dashoffset
         self.stroke_opacity = stroke_opacity
         self.opacity = opacity
+        self.transform = transform
 
     def visible(self):
         def _visible(fill, opacity):
@@ -75,14 +78,14 @@ class SVGShape:
             self.stroke, self.stroke_opacity
         )
 
-    def bounding_box(self, tolerance) -> Rect:
-        x1, y1, x2, y2 = svg_pathops.bounding_box(self, tolerance)
+    def bounding_box(self) -> Rect:
+        x1, y1, x2, y2 = svg_pathops.bounding_box(self)
         return Rect(x1, y1, x2 - x1, y2 - y1)
 
-    def transform(self, transform: Affine2D, tolerance: float):
-        return svg_pathops.transform(self, transform, tolerance)
+    def apply_transform(self, transform: Affine2D):
+        return svg_pathops.transform(self, transform)
 
-    def as_path(self, tolerance) -> "SVGPath":
+    def as_path(self) -> "SVGPath":
         raise NotImplementedError("You should implement as_path")
 
     def absolute(self, inplace=False) -> "SVGShape":
@@ -145,7 +148,7 @@ class SVGPath(SVGShape):
     def end(self):
         self._add("z")
 
-    def as_path(self, tolerance) -> "SVGPath":
+    def as_path(self) -> "SVGPath":
         return self
 
     def __iter__(self):
@@ -353,9 +356,9 @@ class SVGCircle(SVGShape):
     cx: float = 0
     cy: float = 0
 
-    def as_path(self, tolerance) -> SVGPath:
+    def as_path(self) -> SVGPath:
         *shape_fields, r, cx, cy = dataclasses.astuple(self)
-        path = SVGEllipse(rx=r, ry=r, cx=cx, cy=cy).as_path(tolerance)
+        path = SVGEllipse(rx=r, ry=r, cx=cx, cy=cy).as_path()
         path._copy_common_fields(*shape_fields)
         return path
 
@@ -368,7 +371,7 @@ class SVGEllipse(SVGShape):
     cx: float = 0
     cy: float = 0
 
-    def as_path(self, tolerance) -> SVGPath:
+    def as_path(self) -> SVGPath:
         *shape_fields, rx, ry, cx, cy = dataclasses.astuple(self)
         path = SVGPath()
         # arc doesn't seem to like being a complete shape, draw two halves
@@ -388,7 +391,7 @@ class SVGLine(SVGShape):
     x2: float = 0
     y2: float = 0
 
-    def as_path(self, tolerance) -> SVGPath:
+    def as_path(self) -> SVGPath:
         *shape_fields, x1, y1, x2, y2 = dataclasses.astuple(self)
         path = SVGPath()
         path.M(x1, y1)
@@ -402,7 +405,7 @@ class SVGLine(SVGShape):
 class SVGPolygon(SVGShape):
     points: str = ""
 
-    def as_path(self, tolerance) -> SVGPath:
+    def as_path(self) -> SVGPath:
         *shape_fields, points = dataclasses.astuple(self)
         if self.points:
             path = SVGPath(d="M" + self.points + " z")
@@ -417,7 +420,7 @@ class SVGPolygon(SVGShape):
 class SVGPolyline(SVGShape):
     points: str = ""
 
-    def as_path(self, tolerance) -> SVGPath:
+    def as_path(self) -> SVGPath:
         *shape_fields, points = dataclasses.astuple(self)
         if points:
             path = SVGPath(d="M" + self.points)
@@ -445,7 +448,7 @@ class SVGRect(SVGShape):
         self.rx = min(self.rx, self.width / 2)
         self.ry = min(self.ry, self.height / 2)
 
-    def as_path(self, tolerance) -> SVGPath:
+    def as_path(self) -> SVGPath:
         *shape_fields, x, y, w, h, rx, ry = dataclasses.astuple(self)
         path = SVGPath()
         path.M(x + rx, y)
